/*---------------------------------------------------------------------------\
| Project:			Generic LV2 PIC18F458 CAN node firmware
|
| File:				exceptions.c
|
| Description:		Handles exceptions and error and other Bad Things
|
| Global Routines:	throwWarning()
|
| Local Routines:	None
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Created.
\---------------------------------------------------------------------------*/


//------------------------------------------------------------------------
//  #includes
//------------------------------------------------------------------------

#include <pic18.h>    	// Include for PICC-18
#include "pic18fxx8.h"	// Register definitions for the PIC18F458
#include "project.h"	// Includes for the project (misc)
#include "excepts.h"	// Includes for exception handling

/*---------------------------------------------------------------------------\
| Function:		ThrowWarning
|
| Purpose:		Log the list of warnings.
|
| Discussion:	Put a list of errors in a circular buffer.
|
| Expects:		Nothing.
|
| Arguments:	WarningMessage: WARNING_MESSAGE type of warning message.
|
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Stolen from ADG code.
\---------------------------------------------------------------------------*/

void ThrowWarning (enum WARNING_MESSAGES warningMessage)
{
	static	uint8_t	warningMessageLog[WARNINGLOGSIZE];
	static	uint8_t	index;

	// Log the message to an array of bytes.

	warningMessageLog[index] = warningMessage;

	// Roll over the index to 0 and overwrite the log if we get too many
	// warning messages.

	if ( index < (WARNINGLOGSIZE-1) )
		++index;
	else
		index = 0;

	ErrorLedOn();
}



/*---------------------------------------------------------------------------\
| Function:		ThrowWarning_LP
|
| Purpose:		Log the list of warnings FOR ALL LOW PRIORITY INTERRUPT
|				ROUTINES
|
| Discussion:	Put a list of errors in a circular buffer.
|
| Expects:		Nothing.
|
| Arguments:	WarningMessage: WARNING_MESSAGE type of warning message.
|
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Stolen from ADG code.
\---------------------------------------------------------------------------*/

void ThrowWarning_LP (enum WARNING_MESSAGES warningMessage)
{
	static	uint8_t	warningMessageLog[WARNINGLOGSIZE];
	static	uint8_t	index;

	// Log the message to an array of bytes.

	warningMessageLog[index] = warningMessage;

	// Roll over the index to 0 and overwrite the log if we get too many
	// warning messages.

	if ( index < (WARNINGLOGSIZE-1) )
		++index;
	else
		index = 0;

	ErrorLedOn();
}


/*---------------------------------------------------------------------------\
| Function:		ThrowWarning_HP
|
| Purpose:		Log the list of warnings FOR ALL HIGH PRIORITY INTERRUPT
|				ROUTINES
|
| Discussion:	Put a list of errors in a circular buffer.
|
| Expects:		Nothing.
|
| Arguments:	WarningMessage: WARNING_MESSAGE type of warning message.
|
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Stolen from ADG code.
\---------------------------------------------------------------------------*/

void ThrowWarning_HP (enum WARNING_MESSAGES warningMessage)
{
	static	uint8_t	warningMessageLog[WARNINGLOGSIZE];
	static	uint8_t	index;

	// Log the message to an array of bytes.

	warningMessageLog[index] = warningMessage;

	// Roll over the index to 0 and overwrite the log if we get too many
	// warning messages.

	if ( index < (WARNINGLOGSIZE-1) )
		++index;
	else
		index = 0;

	ErrorLedOn();
}

