/*---------------------------------------------------------------------------\
| Project:	Generic LV2 PIC18F458 CAN node firmware
|
| File:		interrupts.h
|
| Descr.:	Includes for the serial.c module
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Created.
\---------------------------------------------------------------------------*/

#ifndef _INTS_H	// Don't include more than once (last line = #endif)
#define _INTS_H

//------------------------------------------------------------------------
// Typedefs
//------------------------------------------------------------------------

enum INTERRUPT_TYPE
{
	LOW_PRIORITY_INT = 0,
	HIGH_PRIORITY_INT
};

//------------------------------------------------------------------------
// #defines
//------------------------------------------------------------------------


//------------------------------------------------------------------------
// Global function declarations
//------------------------------------------------------------------------

void InitializeInterrupts (void);

void interrupt low_priority LowPriorityISR 	(void);
void interrupt 				HighPriorityISR	(void);


//------------------------------------------------------------------------
// #define'd function declarations (for easier reading)
//------------------------------------------------------------------------


#define	EnablePrioritizedInts()		(IPEN = 1)
#define	DisablePrioritizedInts()	(IPEN = 0)

#define	EnableHighPriorityInts()	(GIEH = 1)
#define	DisableHighPriorityInts()	(GIEH = 0)

#define EnableLowPriorityInts()		(GIEL = 1)
#define DisableLowPriorityInts()	(GIEL = 0)


//------------------------------------------------------------------------
// #define'd registers (for easier reading)
//------------------------------------------------------------------------

#define Timer2PrioritySetting		TMR2IP
#define Timer2InterruptPending		TMR2IF
#define	Timer2InterruptEnabled		TMR2IE


//#define Int0PrioritySetting		INT0IP - MUST be high priority (or off)
#define Int0InterruptPending		INT0IF
#define	Int0InterruptEnabled		INT0IE

#define Int1PrioritySetting			INT1IP
#define Int1InterruptPending		INT1IF
#define	Int1InterruptEnabled		INT1IE


#define AdcPrioritySetting			ADIP
#define AdcInterruptPending			ADIF
#define	AdcInterruptEnabled			ADIE


#define	SerialTxPrioritySetting		TXIP
#define SerialTxInterruptPending	TXIF
#define SerialTxInterruptEnabled	TXIE

#define	SerialRxPrioritySetting		RCIP
#define SerialRxInterruptPending	RCIF
#define SerialRxInterruptEnabled	RCIE


#define CanTxb2PrioritySetting		TXB2IP
#define CanTxb2InterruptPending		TXB2IF
#define CanTxb2InterruptEnabled		TXB2IE

#define CanTxb1PrioritySetting		TXB1IP
#define CanTxb1InterruptPending		TXB1IF
#define CanTxb1InterruptEnabled		TXB1IE

#define CanTxb0PrioritySetting		TXB0IP
#define CanTxb0InterruptPending		TXB0IF
#define CanTxb0InterruptEnabled		TXB0IE

#define CanRxb0PrioritySetting		RXB0IP
#define CanRxb0InterruptPending		RXB0IF
#define CanRxb0InterruptEnabled		RXB0IE

#define CanRxb1PrioritySetting		RXB1IP
#define CanRxb1InterruptPending		RXB1IF
#define CanRxb1InterruptEnabled		RXB1IE

#define CanErrPrioritySetting		ERRIP
#define CanErrInterruptPending		ERRIF
#define CanErrInterruptEnabled		ERRIE

//------------------------------------------------------------------------
// Misc #defines
//------------------------------------------------------------------------

// Choose whether an interupt is off, low priority or high priority.

#define	INTS_INTERRUPT_OFF				0
#define	INTS_LOW_PRIORITY_INTERRUPT		1
#define	INTS_HIGH_PRIORITY_INTERRUPT	2

#define	INTS_TIMER2_INT_PRIORITY		INTS_HIGH_PRIORITY_INTERRUPT

#define INTS_INT0_INT_PRIORITY			INTS_INTERRUPT_OFF	// INT0 IS OFF or HIGHPRIORITY
#define INTS_INT1_INT_PRIORITY			INTS_INTERRUPT_OFF

#define INTS_ADC_INT_PRIORITY			INTS_INTERRUPT_OFF

#define	INTS_SERIAL_TX_INT_PRIORITY		INTS_INTERRUPT_OFF
#define	INTS_SERIAL_RX_INT_PRIORITY		INTS_INTERRUPT_OFF

#define	INTS_CAN_TX2_INT_PRIORITY		INTS_LOW_PRIORITY_INTERRUPT
#define	INTS_CAN_TX1_INT_PRIORITY		INTS_LOW_PRIORITY_INTERRUPT
#define	INTS_CAN_TX0_INT_PRIORITY		INTS_LOW_PRIORITY_INTERRUPT
#define	INTS_CAN_RX0_INT_PRIORITY		INTS_LOW_PRIORITY_INTERRUPT
#define	INTS_CAN_RX1_INT_PRIORITY		INTS_LOW_PRIORITY_INTERRUPT
#define	INTS_CAN_ERR_INT_PRIORITY		INTS_INTERRUPT_OFF


// IF MORE INTERRUPTS ARE ADDED HERE: Don't forget to set the interrupt
// priority bits in InitializeInterrupts in ints.c

//------------------------------------------------------------------------
// Global variable declarations (extern)
//------------------------------------------------------------------------

// None


#endif			// _INTS_H
