/*---------------------------------------------------------------------------\
| Project:			Generic LV2 PIC18F458 CAN node firmware
|
| File:				main.c
|
| Description:		Mainline routines.
|
| Global Routines:	Main()
|
| Local Routines:	None
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Stolen from ADG code.
\---------------------------------------------------------------------------*/


//------------------------------------------------------------------------
//  #includes
//------------------------------------------------------------------------

#include <pic18.h>    	// Include for PICC-18
#include "pic18fxx8.h"	// Register definitions for the PIC18F458
#include "project.h"	// Includes for the project (Globals + misc)
#include "main.h"		// Includes for the mainline
#include "ints.h"		// Includes for interrupts
#include "excepts.h"	// Includes for exception handling
#include "ports.h"		// Includes for the port peripherals
#include "timer2.h"		// Includes for the Timer2 peripheral
#include "serial.h"		// Includes for the serial peripheral (UART )
#include "can.h"		// Includes for the CAN peripheral


// Note that we'll also need the linker file "18F458.LKR"
// which should be added to the Project: Edit Project dialog via
// "Add Node". Be SURE to add files in the MCC18 directory (NOT
// from the MPLAB directory).




/*---------------------------------------------------------------------------\
| Function:		main
|
| Purpose:		Run all Mainline code
|
| Discussion:	Doesn't do much, huh?
|
| Expects:		Uh let's see... nothing.
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 02/10/2002 | Created if you can call it that.
\---------------------------------------------------------------------------*/

void main (void)
{
	static CanMessage_t	tempMsg;
	static CanMessage_t	tempMsg2;

	// Initialize everything and its brother

	Initialize();

	// TEST TEST TEST

	tempMsg.header.all = (0x0200 << 5);
	tempMsg.header.bits.length = 1;
	tempMsg.data[0] = 0x00;

	SendCanMessage(&tempMsg);


	// Loop for ever...and......ev....er....and.......ev............er.

	while (TRUE)
	{
		if (gTimer2Flag)
		{
			++tempMsg.data[0];
			SendCanMessage(&tempMsg);
			gTimer2Flag = 0;
		}

		if (canMessageAvailable)
		{
			GetCanMessage(&tempMsg2);
			SendCanMessage(&tempMsg2);
		}
	}

}




/*---------------------------------------------------------------------------\
| Function:		Initialize
|
| Purpose:		Initialize everything. Really.
|
| Discussion:	Did I mention initialization?
|
| Expects:		to be called after a RESET - eg, registers reset to known
|				values and and interrupts off.
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 02/10/2002 | Created if you can call it that.
\---------------------------------------------------------------------------*/

void Initialize (void)
{

	/*
		EVENTUALLY: Check for a reset: If there hasn't been a reset,
		then something has gone horribly wrong. Do a SOFTWARE RESET
		here to put everything in a known state.
	*/

	// Setting up the CAN bus peripheral: We're passing constants
	// to the initialization routine so that we can just set the
	// initialize initialization :) here.

	const CanHeader_t canMaskB0 = (0x07FF << 5);
	const CanHeader_t canMaskB1 = (0x07FF << 5);
	const CanHeader_t CanFilterB0F0 = (0x07FC <<5);
	const CanHeader_t CanFilterB0F1 = (0x0000 << 5);
	const CanHeader_t CanFilterB1F2 = (0x0000 << 5);
	const CanHeader_t CanFilterB1F3 = (0x0000 << 5);
	const CanHeader_t CanFilterB1F4 = (0x0000 << 5);
	const CanHeader_t CanFilterB1F5 = (0x0000 << 5);

	// Get the outputs stabilized FIRST.

	InitializePorts();

	// Turn on serial transmitter and receiver. Turn on receiver interrupts
	// but leave the transmitter interrupts off (we'll turn them on when
	// there's actual data to send over the port). Make both interrupts
	// low priority, and se the bit rate to 9600bps.

	InitializeSerial (	SERIAL_TRANSMIT_ENABLE
						| SERIAL_TRANSMIT_DISABLE_INTS
						| SERIAL_RECEIVE_ENABLE
						| SERIAL_RECEIVE_DISABLE_INTS
						| SERIAL_BITRATE_9600 );

	// Turn on timer2, HP interrupts @ 1KHz

	InitializeTimer2 (	TIMER2_ENABLE
						| TIMER2_ENABLE_INTS
						| TIMER2_1KHZ );

	// Turn on CAN: See const variable declarations above
	// for the values. Note that as soon as we initialize the
	// the bus, we can start to receive messages, so be sure
	// that interrupts are enabled VERY SOON after this call
	// (No more than about a  message length, which at top
	// speed is about 1/22KHz = 45us which at 20MHz is only
	// 250 instructions.

	InitializeCan (	CAN_BITRATE_1MBPS,
					canMaskB0,			// Mask RXB0
					canMaskB1,			// Mask RXB1
					CanFilterB0F0,		// Filter RXB0 F0
					CanFilterB0F1,		// Filter RXB0 F1
					CanFilterB1F2,		// Filter RXB1 F2
					CanFilterB1F3,		// Filter RXB1 F3
					CanFilterB1F4,		// Filter RXB1 F4
					CanFilterB1F5);		// Filter RXB1 F5

	// Initialize variables before start up

	InitializeVariables();

	// Initialize interrupts

	InitializeInterrupts();

	// DO NO FURTHER INITIALIZATION AFTER INTERRUPTS SINCE WE'RE OFF AND
	// RUNNING ONCE THEY'RE ENABLED.
}





/*---------------------------------------------------------------------------\
| Function:		InitializeVariables
|
| Purpose:		Initialize all mainline variables
|
| Discussion:	Sure.
|
| Expects:		To be called before interrupts enabled, although it's not
|				a requirement.
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Created.
\---------------------------------------------------------------------------*/


void	InitializeVariables (void)
{
	/* Do nothing */;
}



